Index: ash/common/wm_shell.h |
diff --git a/ash/common/wm_shell.h b/ash/common/wm_shell.h |
index c6d79223af4be922fcb710e55588198f06ec9d36..f1e45ddbce596a8747ffe99b4acec116719004d6 100644 |
--- a/ash/common/wm_shell.h |
+++ b/ash/common/wm_shell.h |
@@ -34,7 +34,7 @@ class Insets; |
class Point; |
} |
-namespace shell { |
+namespace service_manager { |
class Connector; |
} |
@@ -181,7 +181,7 @@ class ASH_EXPORT WmShell { |
return window_selector_controller_.get(); |
} |
// Returns true when ash is running as a shell::Service. |
virtual bool IsRunningInMash() const = 0; |
virtual WmWindow* NewWindow(ui::wm::WindowType window_type, |
@@ -181,7 +181,7 @@ class ASH_EXPORT WmShell { |
return window_selector_controller_.get(); |
} |
- // Returns true when ash is running as a shell::Service. |
+ // Returns true when ash is running as a service_manager::Service. |
virtual bool IsRunningInMash() const = 0; |
virtual WmWindow* NewWindow(ui::wm::WindowType window_type, |